==> taboola_sdk-0.0.1%2B3.tar.gz: example/lib/screens/taboola_listview_screen.dart <==
import 'package:flutter/material.dart';

import 'package:taboola_sdk/taboola.dart';
import 'package:taboola_sdk/standard/taboola_standard_listener.dart';
import 'package:taboola_sdk/standard/taboola_standard.dart';
import 'package:taboola_sdk/utils/logger.dart';
import 'package:english_words/english_words.dart';


class TaboolaListViewScreen extends StatelessWidget {

  final List <WordPair> _suggestions = <WordPair>[];
  final TextStyle _biggerFont = const TextStyle(fontSize: 18);

  TaboolaStandardBuilder _taboolaStandardBuilder;
  TaboolaStandardListener _taboolaStandardListener;

  TaboolaStandard _taboolaStandard;

  TaboolaListViewScreen(String publisher, String pageUrl, String pageType, String placement, String mode) {
    FlutterProject.current().android;
    final File manifest = androidProject.appManifestFile;



    Taboola.init(PublisherInfo(publisher));
    _taboolaStandardBuilder = Taboola.getTaboolaStandardBuilder(pageUrl, pageType);
    _taboolaStandardListener = TaboolaStandardListener(taboolaDidResize,taboolaDidShow,taboolaDidFailToLoad,taboolaDidClickOnItem);
    _taboolaStandard = _taboolaStandardBuilder.build(placement, mode,true, _taboolaStandardListener);
  }

  @override
  Widget build(BuildContext context) {
    return CustomScrollView(
      controller: _taboolaStandard.scrollController,
      slivers: <Widget>[
        SliverList(
            delegate: new SliverChildListDelegate(_buildList(20))
        ),
        SliverToBoxAdapter(
          child: _taboolaStandard,
        ),
      ],
    );
  }

  List _buildList(int count) {
    List<Widget> listItems = List();

    for (int i = 0; i < count; i++) {
      listItems.add(new Padding(padding: new EdgeInsets.all(20.0),
          child: new Text(
              'Item ${i.toString()}',
              style: new TextStyle(fontSize: 25.0)
          )
      ));
    }

    return listItems;
  }

//  @override
//  Widget build(BuildContext context) {
//    return _buildSuggestions(context);
//  }

  Widget _buildSuggestions(BuildContext buildContext) {
    return ListView.builder(
      controller: _taboolaStandard.scrollController,
      padding: const EdgeInsets.all(16),
      itemCount: 20,
      itemBuilder: (BuildContext _context, int i) {
        if (i.isOdd) {
          return Divider(color: Colors.green,);
        }

        final int index = i ~/ 2;
        if (index >= _suggestions.length) {
          _suggestions.addAll(generateWordPairs().take(10));
        }
        if (i < 18) {
          return _buildRow(_suggestions[index]);
        } else {
          return _taboolaStandard;
        }

      },
    );
  }

  Widget _buildRow(WordPair pair) {
    return ListTile(
      title: Text(
        pair.asPascalCase,
        style: _biggerFont,
      ),
    );
  }

  //Taboola Standard listeners
  void taboolaDidShow(String placement) {
    Logger.log("taboolaDidShow");
  }

  void taboolaDidResize(String placement, double height) {
    Logger.log("publisher did get height $height");
  }

  void taboolaDidFailToLoad(String placement, String error) {
    print("publisher placement:$placement did fail with an error:$error");
  }

  bool taboolaDidClickOnItem(String placement, String itemId, String clickUrl, bool organic) {
    print("publisher did cilck on item:$itemId with clickUrl:$clickUrl in placement:$placement of organic:$organic");
    return true;
  }
}

==> taboola_sdk-0.0.2%2B3.tar.gz: example/lib/screens/taboola_listview_screen.dart <==
import 'package:flutter/material.dart';

import 'package:taboola_sdk/taboola.dart';
import 'package:taboola_sdk/standard/taboola_standard_listener.dart';
import 'package:taboola_sdk/standard/taboola_standard.dart';
import 'package:taboola_sdk/utils/logger.dart';
import 'package:english_words/english_words.dart';

class TaboolaListViewScreen extends StatelessWidget {

  final List <WordPair> _suggestions = <WordPair>[];
  final TextStyle _biggerFont = const TextStyle(fontSize: 18);

  TaboolaStandardBuilder _taboolaStandardBuilder;
  TaboolaStandardListener _taboolaStandardListener;

  TaboolaStandard _taboolaStandard;

  TaboolaListViewScreen(String publisher, String pageUrl, String pageType, String placement, String mode) {
    Taboola.init(PublisherInfo(publisher));
    _taboolaStandardBuilder = Taboola.getTaboolaStandardBuilder(pageUrl, pageType);
    _taboolaStandardListener = TaboolaStandardListener(taboolaDidResize,taboolaDidShow,taboolaDidFailToLoad,taboolaDidClickOnItem);
    _taboolaStandard = _taboolaStandardBuilder.build(placement, mode, true, _taboolaStandardListener);
  }

  @override
  Widget build(BuildContext context) {
    return CustomScrollView( //TODO: try and wrap this in a container to limit widtg and height.. see if it's related to the error
      controller: _taboolaStandard.scrollController,
      slivers: <Widget>[
        SliverList(
            delegate: new SliverChildListDelegate(_buildList(20))
        ),
        SliverToBoxAdapter(
          child: _taboolaStandard,
        ),
      ],
    );
  }

  List _buildList(int count) {
    List<Widget> listItems = List();

    for (int i = 0; i < count; i++) {
      listItems.add(new Padding(padding: new EdgeInsets.all(20.0),
          child: new Text(
              'Item ${i.toString()}',
              style: new TextStyle(fontSize: 25.0)
          )
      ));
    }

    return listItems;
  }

//  @override
//  Widget build(BuildContext context) {
//    return _buildSuggestions(context);
//  }

  Widget _buildSuggestions(BuildContext buildContext) {
    return ListView.builder(
      controller: _taboolaStandard.scrollController,
      padding: const EdgeInsets.all(16),
      itemCount: 20,
      itemBuilder: (BuildContext _context, int i) {
        if (i.isOdd) {
          return Divider(color: Colors.green,);
        }

        final int index = i ~/ 2;
        if (index >= _suggestions.length) {
          _suggestions.addAll(generateWordPairs().take(10));
        }
        if (i < 18) {
          return _buildRow(_suggestions[index]);
        } else {
          return _taboolaStandard;
        }

      },
    );
  }

  Widget _buildRow(WordPair pair) {
    return ListTile(
      title: Text(
        pair.asPascalCase,
        style: _biggerFont,
      ),
    );
  }

  //Taboola Standard listeners
  void taboolaDidShow(String placement) {
    Logger.log("taboolaDidShow");
  }

  void taboolaDidResize(String placement, double height) {
    Logger.log("publisher did get height $height");
  }

  void taboolaDidFailToLoad(String placement, String error) {
    print("publisher placement:$placement did fail with an error:$error");
  }

  bool taboolaDidClickOnItem(String placement, String itemId, String clickUrl, bool organic) {
    print("publisher did cilck on item:$itemId with clickUrl:$clickUrl in placement:$placement of organic:$organic");
    return false;
  }
}
